#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-7ewYqPvIGXBdJSg8svCcD
key:                  vty-crossplatform-0.4.0.0-7ewYqPvIGXBdJSg8svCcD
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  b6bebad54d5cbc8f7d3d124829e047eb
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-7ewYqPvIGXBdJSg8svCcD
depends:
    base-4.18.2.1 vty-6.2-9lKSHYUWnYPKzLKOgWpEqJ
    vty-unix-0.2.0.0-Fz7v9uMfv0UJNpaenSAJTc

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

